Citation
========

If you use iminuit in a scientific work, please cite us ❤️. A generic BibTeX entry is::

    @article{iminuit,
      author={Hans Dembinski and Piti Ongmongkolkul et al.},
      title={scikit-hep/iminuit},
      DOI={10.5281/zenodo.3949207},
      publisher={Zenodo},
      year={2020},
      month={Dec},
      url={https://doi.org/10.5281/zenodo.3949207}
    }

The DOI and URL in this entry point always to the latest release of iminuit. You can also cite the actual release that you used, please follow the `Zenodo link <https://doi.org/10.5281/zenodo.3949207>`_, which offers entries for common bibliography formats for all iminuit releases.

The recommended scientific reference for the MINUIT algorithms is::

    @article{James:1975dr,
        author = "James, F. and Roos, M.",
        title = "{Minuit: A System for Function Minimization and Analysis of the Parameter Errors and Correlations}",
        reportNumber = "CERN-DD-75-20",
        doi = "10.1016/0010-4655(75)90039-9",
        journal = "Comput. Phys. Commun.",
        volume = "10",
        pages = "343--367",
        year = "1975"
    }
